==> igniteui-react-charts-19.0.0.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.ah = null;
        }
        j(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.agy != null;
                    }
                    break;
            }
        }
        ac(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.k("ShowGridlines", 2, a.agy != null);
                    break;
            }
        }
        s(a, b) {
            let c = a;
            if (this.h(b, "ShowGridlines")) {
                if (c.agy == null) {
                    if (this.ah != null) {
                        c.agy = this.ah;
                    }
                    else {
                        c.agy = c.dataChart.aa5;
                    }
                }
            }
            else {
                if (c.agy != null) {
                    this.ah = c.agy;
                    c.agy = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = /*@__PURE__*/ markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();

==> igniteui-react-charts-19.0.1.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.ah = null;
        }
        j(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.ahg != null;
                    }
                    break;
            }
        }
        ac(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.k("ShowGridlines", 2, a.ahg != null);
                    break;
            }
        }
        s(a, b) {
            let c = a;
            if (this.h(b, "ShowGridlines")) {
                if (c.ahg == null) {
                    if (this.ah != null) {
                        c.ahg = this.ah;
                    }
                    else {
                        c.ahg = c.dataChart.abh;
                    }
                }
            }
            else {
                if (c.ahg != null) {
                    this.ah = c.ahg;
                    c.ahg = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = /*@__PURE__*/ markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();
